==> kdeaddons-2.2.2.tar.bz2: kdeaddons-2.2.2/konq-plugins/validators/plugin_validators.h <==
/* This file is part of Validators
 *
 *  It's a merge of the HTML- and the CSSValidator
 *
 *  Copyright (C) 2001 by  Richard Moore <rich@kde.org>
 *                         Andreas Schlapbach <schlpbch@iam.unibe.ch>
 * 
 *  for information how to write your own plugin see:  
 *    http://developer.kde.org/documentation/tutorials/dot/writing-plugins.html
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public License
 *  along with this library; see the file COPYING.LIB.  If not, write to
 *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 *  Boston, MA 02111-1307, USA.
 **/

/* $Id: plugin_validators.h,v 1.2 2001/07/22 21:29:25 schlpbch Exp $ */

#ifndef __plugin_validators_h
#define __plugin_validators_h

#include <kparts/plugin.h>
#include <klibloader.h>

class KURL;
class KAction;

class PluginValidators : public KParts::Plugin
{
  Q_OBJECT
public:
  PluginValidators( QObject* parent = 0, const char* name = 0 );
  virtual ~PluginValidators();

public slots:
  void slotValidateHTML();
  void slotValidateCSS(); 

private: 
  KActionMenu *m_menu;
  KConfig *m_config;
  KURL m_url, m_uploadUrl;
  KURL m_WWWValidatorUrl, m_WWWValidatorUploadUrl;
  KURL m_CSSValidatorUrl, m_CSSValidatorUploadUrl;

  void validateURL();
};

class ValidatorsFactory : public KLibFactory
{
  Q_OBJECT
public:
  ValidatorsFactory();
  virtual ~ValidatorsFactory();

  virtual QObject* createObject( QObject* parent = 0, const char* pname = 0, 
				 const char* name = "QObject", 
				 const QStringList &args = QStringList() );

  static KInstance *instance();

private:
  static KInstance* s_instance;
};

#endif

==> kdeaddons-3.0.1.tar.bz2: kdeaddons-3.0.1/konq-plugins/validators/plugin_validators.h <==
/* This file is part of Validators
 *
 *  It's a merge of the HTML- and the CSSValidator
 *
 *  Copyright (C) 2001 by  Richard Moore <rich@kde.org>
 *                         Andreas Schlapbach <schlpbch@iam.unibe.ch>
 * 
 *  for information how to write your own plugin see:  
 *    http://developer.kde.org/documentation/tutorials/dot/writing-plugins.html
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public License
 *  along with this library; see the file COPYING.LIB.  If not, write to
 *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 *  Boston, MA 02111-1307, USA.
 **/

/* $Id: plugin_validators.h,v 1.4 2001/11/02 21:03:07 schlpbch Exp $ */

#ifndef __plugin_validators_h
#define __plugin_validators_h

#include <kparts/plugin.h>
#include <klibloader.h>

#include "validatorsdialog.h"

class KAction;
class KURL;

class PluginValidators : public KParts::Plugin
{
  Q_OBJECT
public:
  PluginValidators( QObject* parent, const char* name,
                    const QStringList & );
  virtual ~PluginValidators();

public slots:
  void slotValidateHTML();
  void slotValidateCSS(); 
  void slotConfigure();

private: 
  KActionMenu *m_menu;
  ValidatorsDialog *m_configDialog;

  KHTMLPart* m_part;
  KURL m_WWWValidatorUrl, m_WWWValidatorUploadUrl;
  KURL m_CSSValidatorUrl, m_CSSValidatorUploadUrl;

  void setURLs();
  void validateURL(KURL url, KURL uploadUrl);
};

#endif
